@@ -8,7 +8,12 @@ When the test goes out of scope, your redefined attribute goes back to normal be
 import inspect
 import sys
 import types
-from cStringIO import StringIO
+
+try:
+    from cStringIO import StringIO
+except:
+    from io import StringIO
+    
 class CallableWrapper:
     '''Captures information on a redefined function'''
     never_called = True
@@ -31,17 +36,18 @@ class CallableWrapper:
         # or else the __del__ function will not work correctly
         is_class_method = not inspect.ismethod(rd.old_value)
         func = rd.value
-	self.reset()
+        self.reset()
 
         def tocall(*args, **kwargs):
             self._capture(args, kwargs)
 
             # pop off the redef class variable to keep the
             # faked out function signature the same
-            if is_class_method:
+            try:
+                return func(*args, **kwargs)
+            except:
                 args = args[1:]
-
-            return func(*args, **kwargs)
+                return func(*args, **kwargs)
 
         # @staticmethods need to return a function bound
         #  to the class
@@ -51,7 +57,7 @@ class CallableWrapper:
 
 class Redef(object):
     '''An object that when deleted puts the redefined object back to normal'''
-
+    
     def __init__(self, obj, key, **kwargs):
         '''Make sure you keep the returned Redef object in a variable so that the __del__ function is not called immediately
 
